/**
 * geis.c
 *
 * dBus-based GEIS implementation
 */
#include <geis/geis.h>

#include "geis_instance.h"

GeisStatus
geis_init(GeisWinInfo *win_info, GeisInstance *geis_instance)
{
  *geis_instance = geis_instance_get();
  return GEIS_STATUS_SUCCESS;
}


GeisStatus
geis_finish(GeisInstance geis_instance)
{
  geis_instance_free(geis_instance);
  return GEIS_UNKNOWN_ERROR;
}


GeisStatus
geis_configuration_supported(GeisInstance geis_instance,
                             int          configuration_item)
{
  GeisStatus status = GEIS_STATUS_NOT_SUPPORTED;

  if (!geis_instance)
    return GEIS_BAD_ARGUMENT;

  switch (configuration_item)
  {
    case GEIS_CONFIG_UNIX_FD:
      status = GEIS_STATUS_SUCCESS;
      break;
  }
  return status;
}


GeisStatus
geis_configuration_get_value(GeisInstance  geis_instance,
                             int           configuration_item, 
                             void         *value)
{
  GeisStatus status = GEIS_STATUS_NOT_SUPPORTED;
  switch (configuration_item)
  {
    case GEIS_CONFIG_UNIX_FD:
      *(int *)value = geis_instance_fd(geis_instance);
      status = GEIS_STATUS_SUCCESS;
      break;
  }
  return status;
}


GeisStatus
geis_configuration_set_value(GeisInstance  geis_instance,
                             int           configuration_item,
                             void         *value)
{
  return GEIS_UNKNOWN_ERROR;
}


GeisStatus
geis_event_dispatch(GeisInstance geis_instance)
{
  geis_instance_event_dispatch(geis_instance);
  return GEIS_STATUS_SUCCESS;
}


GeisStatus
geis_input_devices(GeisInstance       geis_instance,
                   GeisInputCallback  callback,
                   void              *cookie)
{
  return GEIS_UNKNOWN_ERROR;
}


GeisStatus
geis_subscribe(GeisInstance         geis_instance,
               GeisInputDeviceId   *input_list,
               const char*         *gesture_list,
               GeisGestureCallback  callback,
               void                *cookie)
{
	return GEIS_UNKNOWN_ERROR;
}


GeisStatus
geis_unsubscribe(GeisInstance     geis_instance,
                 GeisGestureType *gesture_list)

{
	return GEIS_STATUS_SUCCESS;
}

