/**
 * @file geis_instance.c
 * 
 * Copyright 2010 Canonical Ltd.
 *
 * This library is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License as published by the Free
 * Software Foundation; either version 3 of the License, or (at your option) any
 * later version.
 *
 * This library is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE.	 See the GNU Lesser General Public License for
 * more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin St, Fifth Floor, Boston, MA  02110-1301 USA
 */
#include "geis_instance.h"

#include <stdlib.h>


GeisInstance
geis_instance_get(GeisXcbWinInfo* win_info)
{
  GeisInstance instance = calloc(1, sizeof(GeisInstance));
  if (instance)
  {
    instance->xcb = geis_xcb_get(win_info);
  }
  return instance;
}


/**
 * Checks the GeisInstance and indicates, to the best of its ability, if it is
 * valid or not.
 *
 * @returns a nonzero (true) value if the @p instance is valid, 0 (false)
 * otherwise.
 */
int
geis_instance_is_valid(GeisInstance instance)
{
  return (instance != 0 && instance->xcb != 0);
}


GeisStatus
geis_instance_subscribe(GeisInstance         instance,
                        GeisInputDeviceId   *input_list,
                        const char*         *gesture_list,
                        GeisGestureFuncs    *funcs,
                        void                *cookie)
{
  instance->gesture_funcs    = funcs;
  instance->gesture_cookie   = cookie;
  return geis_xcb_subscribe(instance, gesture_list);
}


int
geis_instance_fd(GeisInstance instance)
{
  if (instance == NULL)
    return -1;
    
  return geis_xcb_fd(instance->xcb);
}


void
geis_instance_event_dispatch(GeisInstance instance)
{
  geis_xcb_dispatch(instance);
}


void
geis_instance_free(GeisInstance instance)
{
  geis_xcb_free(instance->xcb);
}
